"use strict";
/*
 * Wire
 * Copyright (C) 2024 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buttonStyle = void 0;
const Button_1 = require("./Button");
const Identity_1 = require("../Identity");
const motions_1 = require("../Identity/motions");
const Text_1 = require("../Text");
const buttonPrimaryStyles = (theme, { backgroundColor, disabled, isActive }) => {
    const activeStyles = {
        backgroundColor: theme.Button.primaryActiveBg,
        border: `1px solid ${theme.Button.primaryActiveBorder}`,
        color: Identity_1.COLOR.WHITE,
    };
    return Object.assign(Object.assign({}, (isActive
        ? activeStyles
        : {
            color: disabled ? theme.Button.primaryDisabledText : theme.general.contrastColor,
            backgroundColor: backgroundColor || disabled ? theme.Button.primaryDisabledBg : theme.Button.primaryBg,
        })), (!disabled && {
        '&:hover, &:focus': {
            backgroundColor: theme.Button.primaryHoverBg,
        },
        '&:focus': {
            border: `1px solid ${theme.Button.primaryFocusBorder}`,
        },
        '&:active': activeStyles,
    }));
};
const buttonSecondaryStyles = (theme, { backgroundColor, disabled, isActive }) => {
    const activeStyles = {
        backgroundColor: theme.Button.secondaryActiveBg,
        border: `1px solid ${theme.Button.secondaryActiveBorder}`,
        color: theme.general.primaryColor,
    };
    return Object.assign(Object.assign({ border: `1px solid ${theme.IconButton.primaryBorderColor}` }, (isActive
        ? activeStyles
        : {
            color: disabled ? theme.Input.placeholderColor : theme.general.color,
            backgroundColor: backgroundColor || disabled ? theme.IconButton.primaryDisabledBgColor : theme.IconButton.primaryBgColor,
        })), (!disabled && {
        '&:hover, &:focus': {
            border: `1px solid ${theme.Button.secondaryHoverBorder}`,
        },
        '&:focus': {
            color: theme.IconButton.primaryActiveFillColor,
        },
        '&:active': activeStyles,
    }));
};
const buttonTertiaryStyles = (theme, { backgroundColor, disabled, isActive }) => {
    const activeStyles = {
        backgroundColor: theme.Button.tertiaryActiveBg,
        color: theme.IconButton.primaryActiveFillColor,
        '& > svg > path': {
            fill: theme.IconButton.primaryActiveFillColor,
        },
    };
    return Object.assign(Object.assign({ border: disabled ? `1px solid ${theme.Button.tertiaryDisabledBorder}` : `1px solid ${theme.Button.tertiaryBorder}`, borderRadius: '12px', fontSize: theme.fontSizes.medium, fontWeight: 700, lineHeight: '1.5rem', padding: '4px 8px', '& > svg > path': {
            fill: disabled ? theme.Input.placeholderColor : theme.general.color,
        } }, (isActive
        ? activeStyles
        : {
            color: disabled ? theme.Input.placeholderColor : theme.general.color,
            backgroundColor: backgroundColor || disabled ? theme.Button.tertiarydisabledBg : theme.Button.tertiaryBg,
        })), (!disabled && {
        '&:hover, &:focus': {
            backgroundColor: theme.Button.tertiaryHoverBg,
            border: `1px solid ${theme.Button.tertiaryHoverBorder}`,
        },
        '&:focus': {
            border: `1px solid ${theme.general.focusColor}`,
        },
        '&:active': activeStyles,
    }));
};
const buttonQuaternaryStyles = ({ backgroundColor, disabled, isActive }) => {
    const activeStyles = {
        backgroundColor: Identity_1.COLOR_V2.GREEN_LIGHT_700,
    };
    return Object.assign(Object.assign({ lineHeight: '1.5rem' }, (isActive
        ? activeStyles
        : {
            color: disabled ? Identity_1.COLOR_V2.GRAY_80 : Identity_1.COLOR_V2.WHITE,
            backgroundColor: backgroundColor || disabled ? Identity_1.COLOR_V2.GRAY_50 : Identity_1.COLOR_V2.GREEN,
        })), (!disabled && {
        '&:hover, &:focus': {
            backgroundColor: Identity_1.COLOR_V2.GREEN_LIGHT_600,
        },
        '&:focus': {
            border: `1px solid ${Identity_1.COLOR_V2.GREEN_LIGHT_700}`,
        },
        '&:active': activeStyles,
    }));
};
const buttonCancelStyles = ({ backgroundColor, disabled, isActive }) => {
    const activeStyles = {
        backgroundColor: Identity_1.COLOR_V2.RED_LIGHT_700,
    };
    return Object.assign(Object.assign({ lineHeight: '1.5rem' }, (isActive
        ? activeStyles
        : {
            color: disabled ? Identity_1.COLOR_V2.GRAY_80 : Identity_1.COLOR_V2.WHITE,
            backgroundColor: backgroundColor || disabled ? Identity_1.COLOR_V2.GRAY_50 : Identity_1.COLOR_V2.RED,
        })), (!disabled && {
        '&:hover, &:focus': {
            backgroundColor: Identity_1.COLOR_V2.RED_LIGHT_600,
        },
        '&:focus': {
            border: `1px solid ${Identity_1.COLOR_V2.RED_LIGHT_700}`,
        },
        '&:active': activeStyles,
    }));
};
const buttonSendStyles = ({ backgroundColor, disabled, isActive }) => {
    const activeStyles = {
        backgroundColor: Identity_1.COLOR_V2.BLUE_LIGHT_700,
    };
    return Object.assign(Object.assign({ width: '40px' }, (isActive
        ? activeStyles
        : {
            backgroundColor: backgroundColor || disabled ? Identity_1.COLOR_V2.GRAY_70 : Identity_1.COLOR_V2.BLUE,
        })), (!disabled && {
        '&:hover, &:focus': {
            backgroundColor: Identity_1.COLOR_V2.BLUE_LIGHT_600,
        },
        '&:focus': {
            border: `1px solid ${Identity_1.COLOR_V2.BLUE_LIGHT_800}`,
        },
        '&:active': activeStyles,
    }));
};
const buttonStyle = (theme, _a) => {
    var { variant = Button_1.ButtonVariant.PRIMARY, backgroundColor, block = false, disabled = false, noCapital = false, bold = true, center = true, color = Identity_1.COLOR.WHITE, fontSize = theme.fontSizes.base, noWrap = true, textTransform = 'none', truncate = true } = _a, props = __rest(_a, ["variant", "backgroundColor", "block", "disabled", "noCapital", "bold", "center", "color", "fontSize", "noWrap", "textTransform", "truncate"]);
    return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, (0, Text_1.textStyle)(theme, Object.assign({ block,
        bold,
        center,
        disabled,
        fontSize,
        noWrap,
        textTransform,
        truncate }, props))), { border: 0, cursor: disabled ? 'default' : 'pointer', display: 'flex', alignItems: 'center', justifyContent: 'center', marginBottom: '16px', padding: 0, outline: 'none', textDecoration: 'none', touchAction: 'manipulation', transition: motions_1.defaultTransition, width: block ? '100%' : 'auto', '&:hover, &:focus': {
            textDecoration: 'none',
        } }), (variant !== Button_1.ButtonVariant.TERTIARY && Object.assign({ borderRadius: variant === Button_1.ButtonVariant.SEND ? '100%' : '16px', height: variant === Button_1.ButtonVariant.SEND ? '40px' : '48px', lineHeight: variant === Button_1.ButtonVariant.SEND ? '40px' : '48px' }, (variant !== Button_1.ButtonVariant.SEND && {
        maxWidth: '100%',
        minWidth: '125px',
        padding: '0 16px',
    })))), (variant === Button_1.ButtonVariant.PRIMARY && buttonPrimaryStyles(theme, props))), (variant === Button_1.ButtonVariant.SECONDARY && buttonSecondaryStyles(theme, props))), (variant === Button_1.ButtonVariant.TERTIARY && buttonTertiaryStyles(theme, props))), (variant === Button_1.ButtonVariant.QUATERNARY && buttonQuaternaryStyles(props))), (variant === Button_1.ButtonVariant.CANCEL && buttonCancelStyles(props))), (variant === Button_1.ButtonVariant.SEND && buttonSendStyles(props)));
};
exports.buttonStyle = buttonStyle;
